#!/usr/bin/perl -w

# Version 0.9
#
# Copyright(C) 2005 Daniel Corbe
# You may freely use, redistribute and modify
# this code.  Use at your OWN RISK.
#  
use strict;
use warnings;

use Data::Dumper;
use Net::SNMP;
use Getopt::Std;

# Reference: http://tools.cisco.com/Support/SNMP/do/BrowseOID.do?local=en&translate=Translate&objectInput=1.3.6.1.2.1.15.3.1.2
# We'll go ahead and assume that if the state is anything other than "ESTABLISHED" that's bad 
my $BGPSTATUSTABLE =
{
	1	=> "IDLE",
	2	=> "CONNECT",
	3	=> "ACTIVE",
	4	=> "OPENSENT",
	5	=> "OPENCONFIRM",
	6	=> "ESTABLISHED"
};	
my(%OPTIONS, $hostname, $community, $sessionip, $sessionstatus);

getopt('H:C:s:', \%OPTIONS);

if (defined($OPTIONS{H}))
{
	$hostname = $OPTIONS{H}
}
else
{
	print "Error: missing -H\n";
	exit(3);
}
if (defined($OPTIONS{C}))
{
	$community = $OPTIONS{C}
}
else
{
	print "Error: missing -C\n";
	exit(3);
}
if (defined($OPTIONS{s}))
{
	$sessionip = $OPTIONS{s}
}
else
{
	print "Error: missing -s\n";
	exit(3);
}

my ($snmp, $error) = Net::SNMP->session(
	-hostname	=> $hostname,
	-community	=> $community);

if (!defined($snmp))
{
	printf("ERROR: %s.\n", $error);
	exit 3;
}

my $walk = '1.3.6.1.2.1.15.3.1.2.' . $sessionip;

#printf("DEBUG: Hostname: $hostname Community: $community Session IP: $sessionip OID: $walk\n");

my $result = $snmp->get_request(
	-varbindlist => [$walk]);

if (!defined($result))
{
	printf("ERROR: %s.\n", $snmp->error);
	exit 3;
}
else
{
	printf("BGP Status is %s\n", $BGPSTATUSTABLE->{$result->{$walk}});
	if ($result->{$walk} ne 6)
	{
		exit(2);
	}
	else
	{
		exit(0);
	}
}

